'use strict';

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function _objectSpread(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};
    var ownKeys = Object.keys(source);

    if (typeof Object.getOwnPropertySymbols === 'function') {
      ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) {
        return Object.getOwnPropertyDescriptor(source, sym).enumerable;
      }));
    }

    ownKeys.forEach(function (key) {
      _defineProperty(target, key, source[key]);
    });
  }

  return target;
}

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.remove = exports.update = exports.put = exports.scan = exports.get = exports.query = void 0;

const query = client => table => async (options = {}) => {
  const response = await client.query(_objectSpread({
    TableName: table
  }, options)).promise();
  return response.Items;
};

exports.query = query;

const get = client => table => async (key, options = {}) => {
  const response = await client.get(_objectSpread({
    TableName: table,
    Key: key
  }, options)).promise();
  return response.Item;
};

exports.get = get;

const scan = client => table => async (options = {}, previous = []) => {
  const response = await client.scan(_objectSpread({
    TableName: table
  }, options)).promise();
  const items = [...previous, ...response.Items];
  const lastKey = response.LastEvaluatedKey;
  if (!lastKey) return items;
  return scan(_objectSpread({}, options, {
    ExclusiveStartKey: lastKey
  }), items);
};

exports.scan = scan;

const put = client => table => async (item, options = {}) => {
  await client.put(_objectSpread({
    TableName: table,
    Item: item
  }, options)).promise();
  return item;
};

exports.put = put;

const update = client => table => async (key, options = {}) => {
  const response = await client.update(_objectSpread({
    TableName: table,
    Key: key,
    ReturnValues: 'ALL_NEW'
  }, options)).promise();
  return response.Attributes;
};

exports.update = update;

const remove = client => table => async (key, options = {}) => {
  const response = await client.delete(_objectSpread({
    TableName: table,
    Key: key,
    ReturnValues: 'ALL_OLD'
  }, options)).promise();
  return response.Attributes;
};

exports.remove = remove;
//# sourceMappingURL=index.js.map
